@@ -33,7 +33,7 @@ def cli():
     parse_list.add_argument("tests", nargs="*")
 
     parse_run = subparsers.add_parser("run", aliases=["r"])
-    parse_run.add_argument("--all", action="store_true", help="Run all")
+    parse_run.add_argument("-a", "--all", action="store_true", help="Run all")
     parse_run.add_argument("tests", nargs="*")
     parse_run.set_defaults(func=cli_run)
     args = parser.parse_args()
